@@ -2,7 +2,7 @@ package Proc::PersistentControl; # -*-perl-*-
 #
 # Author: Michael Staats 2014
 #
-# $Id: PersistentControl.pm 705 2014-12-16 15:41:21Z michael $
+# $Id: PersistentControl.pm 708 2015-02-24 16:37:03Z michael $
 #
 
 =head1 NAME
@@ -225,7 +225,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @ISA = qw(Exporter);
 
-$VERSION = '0.93';
+$VERSION = '0.99';
 
 use strict;
 use File::Path qw(mkpath rmtree); # legacy interface, works with older perls
@@ -605,7 +605,7 @@ sub _get_info_by_uid {
     $ret{_dir} =~ s|/|\\|g if ($^O =~ /^MSWin/); # cosmetics, also works without
 
     my $pidalive = 0;
-    for (my $ntry = 0; $ntry < 4; $ntry++, select(undef, undef, undef, 0.1)) {
+    for (my $ntry = 0; $ntry < 10; $ntry++, select(undef, undef, undef, 0.1)) {
 	# try a few times, just in case this function is called
 	# after the process has terminated but before RC could be written
 	opendir(D, $pdir) or croak "cannot opendir $pdir: $!";
@@ -693,7 +693,7 @@ sub StartProc {
 
     # create a directory for process information
     my $psd = tempdir('PPC-XXXX', DIR => $sdir);
-    croak "Cannot make tempdir: $!" unless ($psd);
+    croak "Cannot make tempdir: $!" unless ($psd and -d $psd);
 
     $psd =~ m/.*(PPC-.*)/;
     my $UID = $1;
