@@ -123,11 +123,17 @@ my $job = Win32::Job->new();
 my $pid = $job->spawn($fullpath, $Arg, { stdin  => 'NUL',
 		      stdout => $out, stderr => $err});
 
-open(PID, '>', $dir . "/pid=$pid"); close(PID);
-
-$job->run($timeout);
-
-my $RC = $job->status()->{$pid}->{exitcode};
+my $RC;
+if (not $job or not $pid) {
+    my $msg = "$0: Could not spawn job to run '$fullpath': $! ($^E)\n";
+    print STDERR $msg;
+    print $err $msg;
+    $RC = 127;
+} else {
+    open(PID, '>', $dir . "/pid=$pid"); close(PID);
+    $job->run($timeout);
+    $RC = $job->status()->{$pid}->{exitcode};
+}
 
 open(RC, '>', $dir . "/RC=$RC"); close(RC);
 open(I, '>>', $dir . "/info");
